/*
 Tecnisa - Tecnologia em Informtica

 Nome: Apurac_GesHosp

 Descrio:
 Procedimento para clculo do faturamento na gesto hospitalar.

 Criao:
 29/07/02 - Roberto A. Lopes Martins

 EXECUTE APURAC_GESHOSP('9999', '0000000002', '0000000001')
 @C:\WIN_PRJ\Sql\End_Conv\Oracle\6300_FAHSTP_Apurac_GesHosp.sql
*/

CREATE OR REPLACE PROCEDURE APURAC_GESHOSP
   (P_CDFILIAL   IN ATENHOSP.CDFILIAL%TYPE,
    P_NRATENHOSP IN ATENHOSP.NRATENHOSP%TYPE,
    P_IDGERANOTA IN APURFATUGH.IDTIPOPRODGH%TYPE DEFAULT 'N')

AS

   V_CDPACIENTE      ATENHOSP.CDPACIENTE%TYPE;
   V_CDCONVPRIN      ATENHOSP.CDCONVPRIN%TYPE;
   V_CDPLCONVPRIN    ATENHOSP.CDPLCONVPRIN%TYPE;
   V_CDCONVCOMP      ATENHOSP.CDCONVCOMP%TYPE;
   V_CDPLCONVCOMP    ATENHOSP.CDPLCONVCOMP%TYPE;
   V_CDTIPOATEN      ATENHOSP.CDTIPOATEN%TYPE;
   V_DTINICATEN      OCUPATHOSP.DTHRINIOCUP%TYPE;
   V_DTFINAATEN      OCUPATHOSP.DTHRFINOCUP%TYPE;
   V_HRINICATEN      PARGERALHOSP.HRVENDIARHOS%TYPE;
   V_HRFINAATEN      PARGERALHOSP.HRVENDIARHOS%TYPE;
   V_HRMEIADIRHOS    PARGERALHOSP.HRMEIADIRHOS%TYPE;
   V_HRDIARINTHOS    PARGERALHOSP.HRDIARINTHOS%TYPE;
   V_HRVENDIARHOS    PARGERALHOSP.HRVENDIARHOS%TYPE;
   V_QTDIARATEHOS    APURFATUGH.QTFATURAMGH%TYPE;
   V_CDCLIENTE       CONVENIO.CDCLIENTE%TYPE;
   V_CDEMPRESA       EMPRESA.CDEMPRESA%TYPE;
   V_CDSERIE         SERIENF.CDSERIE%TYPE;
   V_NRAPURACFAT     NOVOCODIGO.NRSEQUENCIAL%TYPE;
   V_NRLANCTONF      NOVOCODIGO.NRSEQUENCIAL%TYPE;
   V_NRLANCESTQ      NOVOCODIGO.NRSEQUENCIAL%TYPE;
   V_IDNOTAGERADA    APURFATUGH.IDTIPOPRODGH%TYPE;

   CURSOR C_RETIRADA IS                                   /*Medicamentos Retirados*/
      SELECT IRQ.CDPRODUTO, IRT.DTRECRETHOSP, IRQ.CDCENTCUST,
             SUM(NVL(IRT.QTRECRETHOSP,0) - (NVL(IRT.QTDEVRETHOSP,0) + NVL(IRT.QTSUSRETHOSP,0))) AS QTFATUHOSP
      FROM REQUHOSP RQ, ITRETIHOSP IRT, ITREQUHOSP IRQ
      WHERE RQ.CDFILIAL      = P_CDFILIAL       AND
            RQ.NRATENHOSP    = P_NRATENHOSP     AND
            IRT.CDFILIAL     = RQ.CDFILIAL      AND
            IRT.NRREQUHOSP   = RQ.NRREQUHOSP    AND
            IRQ.CDFILIAL     = RQ.CDFILIAL      AND
            IRQ.NRREQUHOSP   = RQ.NRREQUHOSP    AND
            IRQ.NRITREQUHOSP = IRT.NRITREQUHOSP AND
           IRT.QTRECRETHOSP <> 0
      GROUP BY CDPRODUTO, IRT.DTRECRETHOSP, IRQ.CDCENTCUST;

   CURSOR C_ORTEPROTE IS                                  /*Produtos de Orteses e Proteses*/
      SELECT IP.CDPRODUTO, 1 AS QTORTEPROTE, IP.NRPROTESE, IT.DTLANCMOVI
      FROM ITMOVPROTESE IP, ITLANCTOEST IT
      WHERE IP.CDFILIAL     = P_CDFILIAL    AND
            IP.NRATENHOSP   = P_NRATENHOSP  AND
            IP.CDFILMOVIEST = IT.CDFILIAL   AND
            IP.NRLANCESTQ   = IT.NRLANCESTQ AND
            IP.NRSEQUITEM   = IT.NRSEQUITEM;

   CURSOR C_DOACAO IS                                     /*Bolsas utilizadas para doao*/
      SELECT RD.CDPRODUTO, RD.CDHEMOCOMP, RD.DTRECEBDOAC,
             SUM(HD.QTHEMOPRDOAC) AS QTHEMOPRDOAC
      FROM RECEBDOAC RD, HEMOPRDOAC HD
      WHERE RD.CDFILIAL    = P_CDFILIAL    AND
            RD.NRATENHOSP  = P_NRATENHOSP  AND
            HD.CDFILIAL    = RD.CDFILIAL   AND
            HD.NRATENHOSP  = RD.NRATENHOSP
      GROUP BY RD.CDPRODUTO, RD.CDHEMOCOMP, RD.DTRECEBDOAC;

   CURSOR C_PROCEDIMENTO IS
      SELECT PC.CDTABEPROC, PC.CDPROCED,                 /*Procedimentos Requisitados*/
             IP.DTREALPROC, 1 AS QTPROCED, 'P' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC
      WHERE IP.CDFILIAL   = P_CDFILIAL    AND
            IP.NRATENHOSP = P_NRATENHOSP  AND
            IP.CDTABEPROC = PC.CDTABEPROC AND
            IP.CDPROCED   = PC.CDPROCED
      UNION ALL
      SELECT PD.CDTABEPROC, PD.CDPROCED,                 /*Procedimentos Complemetares*/
             IP.DTREALPROC, 1 AS QTPROCED, 'P' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC, PROCCOMP PP, PROCED PD
      WHERE IP.CDFILIAL   = P_CDFILIAL      AND
            IP.NRATENHOSP = P_NRATENHOSP    AND
            IP.CDTABEPROC = PC.CDTABEPROC   AND
            IP.CDPROCED   = PC.CDPROCED     AND
            IP.CDTABEPROC = PP.CDTABEPROC   AND
            IP.CDPROCED   = PP.CDPROCED     AND
            PD.CDTABEPROC = PP.CDTABEPRCOMP AND
            PD.CDPROCED   = PP.CDPROCCOMP
      UNION ALL
      SELECT PP.CDTABEPROC, PP.CDPROCED,        /*Produtos complementares de Procedimentos Requisitados*/
             IP.DTREALPROC, PP.QTPRODPROCED AS QTPROCED, 'A' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC, PRODPROC PP
      WHERE IP.CDFILIAL   = P_CDFILIAL    AND
            IP.NRATENHOSP = P_NRATENHOSP  AND
            IP.CDTABEPROC = PC.CDTABEPROC AND
            IP.CDPROCED   = PC.CDPROCED   AND
            IP.CDTABEPROC = PP.CDTABEPROC AND
            IP.CDPROCED   = PP.CDPROCED
      UNION ALL
      SELECT PR.CDTABEPROC, PR.CDPROCED,        /*Produtos complementares de Procedimentos Complementares*/
             IP.DTREALPROC, PR.QTPRODPROCED AS QTPROCED, 'A' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC, PROCCOMP PP, PROCED PD, PRODPROC PR
      WHERE IP.CDFILIAL   = P_CDFILIAL      AND
            IP.NRATENHOSP = P_NRATENHOSP    AND
            IP.CDTABEPROC = PC.CDTABEPROC   AND
            IP.CDPROCED   = PC.CDPROCED     AND
            IP.CDTABEPROC = PP.CDTABEPROC   AND
            IP.CDPROCED   = PP.CDPROCED     AND
            PD.CDTABEPROC = PP.CDTABEPRCOMP AND
            PD.CDPROCED   = PP.CDPROCCOMP   AND
            IP.CDTABEPROC = PR.CDTABEPROC   AND
            IP.CDPROCED   = PR.CDPROCED
      UNION ALL
      SELECT MP.CDTABEPROC, MP.CDPROCED,         /*Metodos Requisitados*/
             IP.DTREALPROC, PM.QTPRODMETO AS QTPROCED, 'P' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC, METOPROC MP, PRODMETO PM
      WHERE IP.CDFILIAL   = P_CDFILIAL    AND
            IP.NRATENHOSP = P_NRATENHOSP  AND
            IP.CDTABEPROC = PC.CDTABEPROC AND
            IP.CDPROCED   = PC.CDPROCED   AND
            IP.CDTABEPROC = MP.CDTABEPROC AND
            IP.CDPROCED   = MP.CDPROCED   AND
            MP.CDMETODO   = PM.CDMETODO
      UNION ALL
      SELECT MP.CDTABEPROC, MP.CDPROCED,         /*Metodos Complemetares*/
             IP.DTREALPROC, PM.QTPRODMETO AS QTPROCED, 'P' AS IDTIPOPRODGH
      FROM ITREQUPROC IP, PROCED PC, PROCCOMP PP, PROCED PD, METOPROC MP, PRODMETO PM
      WHERE IP.CDFILIAL   = P_CDFILIAL      AND
            IP.NRATENHOSP = P_NRATENHOSP    AND
            IP.CDTABEPROC = PC.CDTABEPROC   AND
            IP.CDPROCED   = PC.CDPROCED     AND
            IP.CDTABEPROC = PP.CDTABEPROC   AND
            IP.CDPROCED   = PP.CDPROCED     AND
            PD.CDTABEPROC = PP.CDTABEPRCOMP AND
            PD.CDPROCED   = PP.CDPROCCOMP   AND
            IP.CDTABEPROC = MP.CDTABEPROC   AND
            IP.CDPROCED   = MP.CDPROCED     AND
            MP.CDMETODO   = PM.CDMETODO
      UNION ALL
      SELECT CDTABEPROC, CDPROCED,               /*Produtos Agregados*/
             SYSDATE AS DTREALPROC, 1 AS QTPROCED, 'A' AS IDTIPOPRODGH
      FROM PROAGRCONV
      WHERE CDFILIAL   = P_CDFILIAL                      AND
            CDCONVENIO = V_CDCONVPRIN                    AND
            CDPLANCONV = NVL(V_CDPLCONVPRIN, CDPLANCONV) AND
            CDTIPOATEN = NVL(V_CDTIPOATEN, CDTIPOATEN);

   CURSOR C_OCUPACAO IS                                /*Dirias da ocupao do atendimento*/
      SELECT TD.CDPRODUTO, OC.CDTIPODEPE, OC.DTHRINIOCUP,
             NVL(OC.DTHRFINOCUP, SYSDATE) DTHRFINOCUP
      FROM OCUPATHOSP OC, TIPODEPE TD
      WHERE OC.CDFILIAL    = P_CDFILIAL   AND
            OC.NRATENHOSP  = P_NRATENHOSP AND
            OC.CDTIPODEPE  = TD.CDTIPODEPE;

   CURSOR C_GERANF IS
      SELECT AP.CDPRODUTO, P.NMPRODUTO, AP.QTFATURAMGH, AP.VRPRECUNITGH, AP.VRDESCONTOGH
      FROM APURFATUGH AP, PRODUTO P
      WHERE AP.CDFILIAL    = P_CDFILIAL   AND
            AP.NRATENHOSP  = P_NRATENHOSP AND
            AP.CDPRODUTO   = P.CDPRODUTO;

   CURSOR C_DELETA_NF IS
      SELECT N.CDFILIAL, N.NRLANCTONF
      FROM APURFATUGH A, NOTAFISCAL N
      WHERE A.CDFILIAL    = P_CDFILIAL   AND
            A.NRATENHOSP  = P_NRATENHOSP AND
            N.CDFILIAL    = A.CDFILIAL   AND
            N.NRAPURACFAT = A.NRAPURACFAT;

/*-------------------------------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------------------------------*/
   PROCEDURE INSERE_APURFATUGH
      (P_CDFILIALGH   IN APURFATUGH.CDFILIAL%TYPE,
       P_NRATENHOSPGH IN APURFATUGH.NRATENHOSP%TYPE,
       P_CDPACIENTEGH IN APURFATUGH.CDPACIENTE%TYPE,
       P_IDTIPOPRODGH IN APURFATUGH.IDTIPOPRODGH%TYPE,
       P_CDPRODUTOGH  IN APURFATUGH.CDPRODUTO%TYPE,
       P_CDPLACONPRGH IN APURFATUGH.CDPLACONPRGH%TYPE,
       P_CDCONVPRINGH IN APURFATUGH.CDCONVPRINGH%TYPE,
       P_CDPLACONCPGH IN APURFATUGH.CDPLACONCPGH%TYPE,
       P_CDCONVCOMPGH IN APURFATUGH.CDCONVCOMPGH%TYPE,
       P_QTFATURAMGH  IN APURFATUGH.QTFATURAMGH%TYPE,
       P_CDTABEPROCGH IN APURFATUGH.CDTABEPROC%TYPE,
       P_CDPROCEDGH   IN APURFATUGH.CDPROCED%TYPE,
       P_CDCENTCUSTGH IN APURFATUGH.CDCENTCUST%TYPE,
       P_CDHEMOCOMPGH IN APURFATUGH.CDHEMOCOMP%TYPE,
       P_DTFATURAMGH  IN APURFATUGH.DTFATURAMGH%TYPE,
       P_NRPROTESEGH  IN APURFATUGH.NRPROTESE%TYPE,
       P_CDTIPODEPEGH IN APURFATUGH.CDTIPODEPE%TYPE,
       P_CDTIPOATEN   IN ATENHOSP.CDTIPOATEN%TYPE)

   AS

      V_NRSEQUITEMGH APURFATUGH.NRSEQUITEMGH%TYPE;
      V_IDCONVFATUGH APURFATUGH.IDCONVFATUGH%TYPE;
      V_CDPRODUTO    APURFATUGH.CDPRODUTO%TYPE;
      V_CDCONVENIO   APURFATUGH.CDCONVPRINGH%TYPE;
      V_CDPLANCONV   APURFATUGH.CDPLACONPRGH%TYPE;
      V_VRPRECOPADR  APURFATUGH.VRPADRUNITGH%TYPE;
      V_VRDESCPADR   APURFATUGH.VRPADRDESCGH%TYPE;
      V_VRINDICE     MOVINDICE.VRINDICE%TYPE;
      V_VRFTAUTOCONV FTAUTOCONV.VRFTAUTOCONV%TYPE;
      V_CDFORNECED   PROTESE.CDFORNECED%TYPE;
      V_VRPEFORNCONV FORMPRPROT.VRPEFORNCONV%TYPE;
      V_VRPEHOSPCONV FORMPRPROT.VRPEHOSPCONV%TYPE;
      V_CDTABEPREC   TABEPREC.CDTABEPREC%TYPE;
      V_VRPEDESVLRPR ITDESCVALRPR.VRPEDESVLRPR%TYPE;
      V_VRFTFUNCMEDI FTFUNCMEDI.VRFTFUNCMEDI%TYPE;
      V_VRPADRPROC   APURFATUGH.VRPADRUNITGH%TYPE;
      V_VRUNITPROC   APURFATUGH.VRPADRUNITGH%TYPE;
      V_VRINDIPROC   MOVINDICE.VRINDICE%TYPE;

   BEGIN

      SELECT NVL(MAX(NRSEQUITEMGH),'0000')
      INTO V_NRSEQUITEMGH
      FROM APURFATUGH
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRATENHOSP = P_NRATENHOSP;

      SELECT MAX(CDPRODUTO)
      INTO V_CDPRODUTO
      FROM PRNAUTCONV
      WHERE CDPRODUTO  = P_CDPRODUTOGH  AND
            CDCONVENIO = P_CDCONVPRINGH AND
            CDPLANCONV = P_CDPLACONPRGH;

      IF V_CDPRODUTO IS NULL THEN
         V_IDCONVFATUGH := 'CP';
         V_CDCONVENIO   := P_CDCONVPRINGH;
         V_CDPLANCONV   := P_CDPLACONPRGH;
      ELSE
         SELECT MAX(CDPRODUTO)
         INTO V_CDPRODUTO
         FROM PRNAUTCONV
         WHERE CDPRODUTO  = P_CDPRODUTOGH  AND
               CDCONVENIO = P_CDCONVCOMPGH AND
               CDPLANCONV = P_CDPLACONCPGH;

         IF V_CDPRODUTO IS NULL THEN
            V_IDCONVFATUGH := 'CC';
            V_CDCONVENIO   := P_CDCONVCOMPGH;
            V_CDPLANCONV   := P_CDPLACONCPGH;
         ELSE
            V_IDCONVFATUGH := 'PA';

            SELECT MAX(CDCONVPART)
            INTO V_CDCONVENIO
            FROM PARGERALHOSP;
         END IF;
      END IF;

--      SELECT MAX(CDCLIENTE), MAX(CDTABEPREC)
--      INTO V_CDCLIENTE, V_CDTABEPREC
--      FROM CONVENIO
--      WHERE CDCONVENIO = V_CDCONVENIO;

      IF P_IDTIPOPRODGH <> 'P' THEN                        /*Verifica descontos no preo da prtese*/
         /* Este select est errado pois deve considerar o campo CDPRPAITABPR*/
         SELECT MAX(VRPRCLITEM)
         INTO V_VRPRECOPADR
         FROM ITEMPRECOCLI IT, TABEVEND TV
         WHERE IT.CDFILIAL     = P_CDFILIALGH   AND
               IT.CDTABEPREC   = V_CDTABEPREC   AND
               IT.CDPRPAITABPR = P_CDPRODUTOGH  AND
               IT.CDPRODUTO    = P_CDPRODUTOGH  AND
               IT.CDCLIENTE    = V_CDCLIENTE    AND
               IT.CDFILIAL     = TV.CDFILIAL    AND
               IT.CDTABEPREC   = TV.CDTABEPREC  AND
               IT.DTINIVGPREC  = TV.DTINIVGPREC AND
               SYSDATE BETWEEN TV.DTINIVGPREC AND TV.DTFINVGPREC;

         /* Este select est errado pois deve considerar o campo CDPRPAITABPR*/
         IF V_VRPRECOPADR IS NULL THEN
            SELECT MAX(VRPRECITEM)
            INTO V_VRPRECOPADR
            FROM ITEMPRECO IT, TABEVEND TV
            WHERE IT.CDFILIAL     = P_CDFILIALGH   AND
                  IT.CDTABEPREC   = V_CDTABEPREC   AND
                  IT.CDPRPAITABPR = P_CDPRODUTOGH  AND
                  IT.CDPRODUTO    = P_CDPRODUTOGH  AND
                  IT.CDFILIAL     = TV.CDFILIAL    AND
                  IT.CDTABEPREC   = TV.CDTABEPREC  AND
                  IT.DTINIVGPREC  = TV.DTINIVGPREC AND
                  SYSDATE BETWEEN TV.DTINIVGPREC AND TV.DTFINVGPREC;
         END IF;
      ELSE
         SELECT SUM(VRPORTEANEST)
         INTO V_VRPRECOPADR
         FROM PROCED
         WHERE CDTABEPROC = P_CDTABEPROCGH AND
               CDPROCED   = P_CDPROCEDGH;
      END IF;

      IF P_IDTIPOPRODGH = 'O' THEN                        /*Verifica descontos no preo da prtese*/
         SELECT MAX(CDFORNECED)
         INTO V_CDFORNECED
         FROM PROTESE
         WHERE CDFILIAL  = P_CDFILIALGH  AND
               CDPRODUTO = P_CDPRODUTOGH AND
               NRPROTESE = P_NRPROTESEGH;

         SELECT (1+(NVL(MAX(VRPEFORNCONV),0)/100)),
                (1+(NVL(MAX(VRPEHOSPCONV),0)/100))
         INTO V_VRPEFORNCONV, V_VRPEHOSPCONV
         FROM FORMPRPROT
         WHERE CDFILIAL   = P_CDFILIALGH  AND
               CDPRODUTO  = P_CDPRODUTOGH AND
               CDFORNECED = V_CDFORNECED  AND
               CDCONVENIO = V_CDCONVENIO;

         V_VRPRECOPADR := ((V_VRPRECOPADR * V_VRPEFORNCONV) * V_VRPEHOSPCONV);
      END IF;

      SELECT NVL(MAX(VRINDICE),1)
      INTO V_VRINDICE
      FROM MOEDUTCONV MU, MOVINDICE MI
      WHERE MU.CDFILIAL   = P_CDFILIALGH                         AND
            MU.CDPRODUTO  = P_CDPRODUTOGH                        AND
            MU.CDCONVENIO = V_CDCONVENIO                         AND
            MU.CDTIPOATEN = P_CDTIPOATEN                         AND
            MU.CDPLANCONV = NVL(V_CDPLANCONV, MU.CDPLANCONV)     AND
            MU.CDTABEPROC = NVL(P_CDTABEPROCGH, MU.CDTABEPROC)   AND
            MU.CDPROCED   = NVL(P_CDPROCEDGH, MU.CDPROCED)       AND
            MU.CDTPINDICE = MI.CDTPINDICE                        AND
            MU.IDPERVALOR = MI.IDPERVALOR                        AND
            MU.CDINDICE   = MI.CDINDICE                          AND
            MI.DTREFIND   = P_DTFATURAMGH;

      V_VRPADRPROC := 0;
      V_VRUNITPROC := 0;
      V_VRINDIPROC := 0;

      IF P_IDTIPOPRODGH = 'P' THEN                        /*Verifica fator de multiplicao da funo mdica do procedimento*/
         V_VRPADRPROC := V_VRPRECOPADR;
         V_VRUNITPROC := V_VRPRECOPADR * V_VRINDICE;
         V_VRINDIPROC := 0;

         FOR C_FATOR IN (SELECT CDFUNCMEDICA, NRFTFUNCMEDI,
                                NVL(VRFTFUNCMPR/100,0) AS VRFTFUNCMPR
                         FROM FTFUNCMPROC
                         WHERE CDFILIAL   = P_CDFILIALGH   AND
                               CDTABEPROC = P_CDTABEPROCGH AND
                               CDPROCED   = P_CDPROCEDGH) LOOP

            SELECT NVL(MAX(VRFTFUNCMEDI)/100,0)
            INTO V_VRFTFUNCMEDI
            FROM FTFUNCMEDI
            WHERE CDFILIAL     = P_CDFILIALGH         AND
                  CDFUNCMEDICA = C_FATOR.CDFUNCMEDICA AND
                  NRFTFUNCMEDI = C_FATOR.NRFTFUNCMEDI;

            V_VRFTFUNCMEDI := V_VRFTFUNCMEDI + C_FATOR.VRFTFUNCMPR;

            V_VRFTFUNCMEDI := (V_VRPRECOPADR * V_VRFTFUNCMEDI);
            V_VRPADRPROC   := V_VRPRECOPADR + (V_VRPADRPROC * V_VRFTFUNCMEDI);

            SELECT NVL(MAX(VRINDICE),V_VRINDICE)
            INTO V_VRINDIPROC
            FROM MOEDUTCONV MU, MOVINDICE MI
            WHERE MU.CDFILIAL     = P_CDFILIALGH                     AND
                  MU.CDPRODUTO    = P_CDPRODUTOGH                    AND
                  MU.CDCONVENIO   = V_CDCONVENIO                     AND
                  MU.CDTIPOATEN   = P_CDTIPOATEN                     AND
                  MU.CDPLANCONV   = NVL(V_CDPLANCONV, MU.CDPLANCONV) AND
                  MU.CDTABEPROC   = P_CDTABEPROCGH                   AND
                  MU.CDPROCED     = P_CDPROCEDGH                     AND
                  MU.CDFUNCMEDICA = C_FATOR.CDFUNCMEDICA             AND
                  MU.CDTPINDICE   = MI.CDTPINDICE                    AND
                  MU.IDPERVALOR   = MI.IDPERVALOR                    AND
                  MU.CDINDICE     = MI.CDINDICE                      AND
                  MI.DTREFIND     = P_DTFATURAMGH;

            V_VRUNITPROC   := V_VRUNITPROC + ((V_VRUNITPROC * V_VRFTFUNCMEDI) * V_VRINDIPROC);
         END LOOP;
      END IF;

      SELECT (1 - (NVL(MAX(ID.VRPEDESVLRPR),0)/100)),
             (NVL(MAX(ID.VRPEDESVLRPR),0)/100)
      INTO V_VRPEDESVLRPR, V_VRDESCPADR
      FROM DESCVALRPR DC, ITDESCVALRPR ID
      WHERE DC.CDFILIAL     = P_CDFILIALGH                       AND
            DC.CDPRODUTO    = P_CDPRODUTOGH                      AND
            DC.CDCONVENIO   = V_CDCONVENIO                       AND
            DC.CDPLANCONV   = NVL(V_CDPLANCONV, DC.CDPLANCONV)   AND
            DC.CDTABEPROC   = NVL(P_CDTABEPROCGH, DC.CDTABEPROC) AND
            DC.CDPROCED     = NVL(P_CDPROCEDGH, DC.CDPROCED)     AND
            DC.CDFILIAL     = ID.CDFILIAL                        AND
            DC.NRDESCVALRPR = ID.NRDESCVALRPR                    AND
            V_VRPRECOPADR BETWEEN VRINDESVLRPR AND VRFIDESVLRPR;

      V_VRDESCPADR  := (V_VRPRECOPADR * V_VRDESCPADR);
      V_VRPRECOPADR := (V_VRPRECOPADR * V_VRPEDESVLRPR);

      V_NRSEQUITEMGH := LPAD(TO_CHAR(TO_NUMBER(V_NRSEQUITEMGH) + 1), 4, '0');

      INSERT INTO APURFATUGH
         (CDFILIAL, NRATENHOSP, NRSEQUITEMGH, CDPACIENTE, IDTIPOPRODGH,
          CDPRODUTO, IDCONVFATUGH, CDPLACONPRGH, CDCONVPRINGH, CDPLACONCPGH, CDCONVCOMPGH,
          QTFATURAMGH, VRPRECUNITGH, VRDESCONTOGH, VRPADRUNITGH, VRPADRDESCGH, CDPROCED,
          CDCENTCUST, NRPROTESE, CDHEMOCOMP, DTFATURAMGH, CDTIPODEPE)
      VALUES
         (P_CDFILIALGH, P_NRATENHOSPGH, V_NRSEQUITEMGH, P_CDPACIENTEGH, P_IDTIPOPRODGH,
          P_CDPRODUTOGH, V_IDCONVFATUGH, P_CDPLACONPRGH, P_CDCONVPRINGH, P_CDPLACONCPGH, P_CDCONVCOMPGH,
          P_QTFATURAMGH, (V_VRPRECOPADR * V_VRINDICE), (V_VRDESCPADR * V_VRINDICE), V_VRPRECOPADR, V_VRDESCPADR, P_CDPROCEDGH,
          P_CDCENTCUSTGH, P_NRPROTESEGH, P_CDHEMOCOMPGH, P_DTFATURAMGH, P_CDTIPODEPEGH);
   END;
/*-------------------------------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------------------------------*/

BEGIN
   V_IDNOTAGERADA := 'N';

   IF P_IDGERANOTA = 'S' THEN
      FOR C_AUX IN C_DELETA_NF LOOP
         DELETA_NF(C_AUX.CDFILIAL, C_AUX.NRLANCTONF);
      END LOOP;
   ELSE
      FOR C_AUX IN C_DELETA_NF LOOP
         V_IDNOTAGERADA := 'S';
      END LOOP;
   END IF;

   IF V_IDNOTAGERADA = 'N' THEN
      DELETE FROM APURFATUGH
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRATENHOSP = P_NRATENHOSP;
   END IF;

   SELECT MAX(CDPACIENTE), MAX(CDCONVPRIN), MAX(CDPLCONVPRIN),
          MAX(CDCONVCOMP), MAX(CDPLCONVCOMP), MAX(CDTIPOATEN)
   INTO V_CDPACIENTE, V_CDCONVPRIN, V_CDPLCONVPRIN,
        V_CDCONVCOMP, V_CDPLCONVCOMP, V_CDTIPOATEN
   FROM ATENHOSP
   WHERE CDFILIAL   = P_CDFILIAL AND
         NRATENHOSP = P_NRATENHOSP;

   FOR C_AUX IN C_RETIRADA LOOP
      INSERE_APURFATUGH(P_CDFILIAL, P_NRATENHOSP, V_CDPACIENTE,
                        'R', 'Produto', V_CDPLCONVPRIN, V_CDCONVPRIN,
                        V_CDPLCONVCOMP, V_CDCONVCOMP, C_AUX.QTFATUHOSP, NULL, NULL,
                        C_AUX.CDCENTCUST, NULL, C_AUX.DTRECRETHOSP, NULL, NULL, V_CDTIPOATEN);
   END LOOP;

   FOR C_AUX IN C_ORTEPROTE LOOP
      INSERE_APURFATUGH(P_CDFILIAL, P_NRATENHOSP, V_CDPACIENTE,
                        'O', 'Produto', V_CDPLCONVPRIN, V_CDCONVPRIN,
                        V_CDPLCONVCOMP, V_CDCONVCOMP, C_AUX.QTORTEPROTE, NULL, NULL,
                        NULL, NULL, C_AUX.DTLANCMOVI, C_AUX.NRPROTESE, NULL, V_CDTIPOATEN);
   END LOOP;

   FOR C_AUX IN C_DOACAO LOOP
      INSERE_APURFATUGH(P_CDFILIAL, P_NRATENHOSP, V_CDPACIENTE,
                        'D', 'Produto', V_CDPLCONVPRIN, V_CDCONVPRIN,
                        V_CDPLCONVCOMP, V_CDCONVCOMP, C_AUX.QTHEMOPRDOAC, NULL, NULL,
                        NULL, C_AUX.CDHEMOCOMP, C_AUX.DTRECEBDOAC, NULL, NULL, V_CDTIPOATEN);
   END LOOP;

   FOR C_AUX IN C_PROCEDIMENTO LOOP
      INSERE_APURFATUGH(P_CDFILIAL, P_NRATENHOSP, V_CDPACIENTE,
                        C_AUX.IDTIPOPRODGH, 'Produto', V_CDPLCONVPRIN, V_CDCONVPRIN,
                        V_CDPLCONVCOMP, V_CDCONVCOMP, C_AUX.QTPROCED, C_AUX.CDTABEPROC, C_AUX.CDPROCED,
                        NULL, NULL, C_AUX.DTREALPROC, NULL, NULL, V_CDTIPOATEN);
   END LOOP;

   FOR C_AUX IN C_OCUPACAO LOOP
      SELECT MAX(HRMEIADIRHOS), MAX(HRDIARINTHOS), MAX(HRVENDIARHOS)
      INTO V_HRMEIADIRHOS, V_HRDIARINTHOS, V_HRVENDIARHOS
      FROM PARGERALHOSP;

      V_HRINICATEN := TO_CHAR(C_AUX.DTHRINIOCUP, 'HH24MI');
      V_HRFINAATEN := TO_CHAR(C_AUX.DTHRFINOCUP, 'HH24MI');

      V_DTINICATEN := ROUND(C_AUX.DTHRINIOCUP);
      V_DTFINAATEN := ROUND(C_AUX.DTHRFINOCUP);

      V_QTDIARATEHOS := (V_DTFINAATEN - V_DTINICATEN);

      /*Verificando hora de incio de ocupao para clculo do numero de dirias*/
      IF V_HRINICATEN < V_HRDIARINTHOS THEN
         V_DTINICATEN   := TO_DATE(TO_CHAR((C_AUX.DTHRINIOCUP - 1), 'DD/MM/YYYY') || V_HRMEIADIRHOS, 'DD/MM/YYYYHH24MI');
         V_QTDIARATEHOS := V_QTDIARATEHOS + 0.5;
      ELSIF V_HRINICATEN > V_HRMEIADIRHOS THEN
         V_DTINICATEN   := TO_DATE(TO_CHAR((C_AUX.DTHRINIOCUP), 'DD/MM/YYYY') || V_HRMEIADIRHOS, 'DD/MM/YYYYHH24MI');
         V_QTDIARATEHOS := V_QTDIARATEHOS - 0.5;
      ELSE
         V_DTINICATEN := TO_DATE(TO_CHAR((C_AUX.DTHRINIOCUP), 'DD/MM/YYYY') || V_HRDIARINTHOS, 'DD/MM/YYYYHH24MI');
      END IF;

      /*Verificando hora final de ocupao para clculo do numero de dirias*/
      IF V_HRFINAATEN < V_HRVENDIARHOS THEN
         V_DTFINAATEN := TO_DATE(TO_CHAR((C_AUX.DTHRFINOCUP), 'DD/MM/YYYY') || V_HRVENDIARHOS, 'DD/MM/YYYYHH24MI');
      ELSIF V_HRFINAATEN < V_HRMEIADIRHOS THEN
         V_DTFINAATEN := TO_DATE(TO_CHAR((C_AUX.DTHRFINOCUP), 'DD/MM/YYYY') || V_HRVENDIARHOS, 'DD/MM/YYYYHH24MI');
         V_QTDIARATEHOS := V_QTDIARATEHOS - 0.5;
      ELSE
         V_QTDIARATEHOS := V_QTDIARATEHOS + 1;
         V_DTFINAATEN   := TO_DATE(TO_CHAR((C_AUX.DTHRFINOCUP + 1), 'DD/MM/YYYY') || V_HRVENDIARHOS, 'DD/MM/YYYYHH24MI');
      END IF;

      INSERE_APURFATUGH(P_CDFILIAL, P_NRATENHOSP, V_CDPACIENTE,
                        'U', 'Produto', V_CDPLCONVPRIN, V_CDCONVPRIN,
                        V_CDPLCONVCOMP, V_CDCONVCOMP, V_QTDIARATEHOS, NULL, NULL,
                        NULL, NULL, C_AUX.DTHRINIOCUP, NULL, C_AUX.CDTIPODEPE, V_CDTIPOATEN);
   END LOOP;

   IF P_IDGERANOTA = 'S' THEN
      SELECT MAX(CDEMPRESA), MAX(CDSERIE)
      INTO V_CDEMPRESA, V_CDSERIE
      FROM FILIAL
      WHERE CDFILIAL = P_CDFILIAL;

      NOVO_CODIGO('APURACFATUR' || P_CDFILIAL, V_NRAPURACFAT);
      V_NRAPURACFAT := SUBSTR(V_NRAPURACFAT,11,10);

      INSERT INTO CTRLAPURFAT
         (CDFILIAL, NRAPURACFAT, CDFILIAPUR, CDCLIENTE,
          DTINIAPURAC, DTFIMAPURAC, IDAPURACOK)
      VALUES
         (P_CDFILIAL, V_NRAPURACFAT, P_CDFILIAL, V_CDCLIENTE,
          ROUND(V_DTINICATEN), ROUND(V_DTFINAATEN), 'S');

      NOVO_CODIGO('LANCNF/FILIAL' || P_CDFILIAL,V_NRLANCTONF);
      V_NRLANCTONF := SUBSTR(V_NRLANCTONF,11,10);

      GERA_NOTAFISCAL_CORPO (P_CDFILIAL,    P_CDFILIAL, V_CDEMPRESA,
                             '01',          V_CDSERIE,  V_CDCLIENTE,
                             ROUND(V_DTFINAATEN),  'FAI',      V_NRLANCTONF,
                             V_NRLANCESTQ,  'N',        V_NRAPURACFAT,
                             V_NRLANCTONF);

      FOR C_AUX IN C_GERANF LOOP
         GERA_NOTAFISCAL_PRODUTO(P_CDFILIAL, V_NRLANCTONF, 'Produto',
                                 'Produto', C_AUX.NMPRODUTO, C_AUX.QTFATURAMGH,
                                 C_AUX.VRPRECUNITGH, C_AUX.VRDESCONTOGH);
      END LOOP;

      GERA_NOTAFISCAL_FECHAMENTO(P_CDFILIAL, V_NRLANCTONF);

      UPDATE APURFATUGH
      SET NRAPURACFAT = V_NRAPURACFAT
      WHERE CDFILIAL   = P_CDFILIAL AND
            NRATENHOSP = P_NRATENHOSP;
   END IF;
END;
/
